@@ -1,10 +1,9 @@
 from .create_tests import CreateTests
-from .settings import ConfigFiles
 
 
-class Autotest(ConfigFiles, CreateTests):
+class Autotest(CreateTests):
     @classmethod
-    def start(cls, folder_path: str = None, app: str = None):
+    def start(cls, folder_path: str = "", app: str = ""):
         cls().create_test_file(
             cls().inspect_folder_for_tests(**{"folder_path": folder_path, "app": app})
         )
